@@ -7,61 +7,69 @@ use Aspect::Pointcut::Or  ();
 use Aspect::Pointcut::And ();
 use Aspect::Pointcut::Not ();
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use overload (
-	# Keep traditional boolification and stringification
+	# Keep traditional Perl boolification and stringification
 	'bool' => sub () { 1 },
 	'""'   => sub { ref $_[0] },
 
 	# Overload bitwise boolean operators to perform logical transformations.
-	'|'    => sub { Aspect::Pointcut::Or->new($_[0],  $_[1]) },
-	'&'    => sub { Aspect::Pointcut::And->new($_[0], $_[1]) },
-	'!'    => sub { Aspect::Pointcut::Not->new($_[0])        },
+	'|'    => sub { Aspect::Pointcut::Or ->new( $_[0], $_[1] ) },
+	'&'    => sub { Aspect::Pointcut::And->new( $_[0], $_[1] ) },
+	'!'    => sub { Aspect::Pointcut::Not->new( $_[0]        ) },
+
+	# Everything else is free to throw an exception
 );
 
-# Default constructor takes a simple list of params
+
+
+
+
+######################################################################
+# Constructor
+
 sub new {
 	my $class = shift;
 	bless [ @_ ], $class;
 }
 
-# TODO: if it is 'eq' we can jusy grab it
-sub match {
-	my ($self, $spec, $sub_name) = @_;
-	return
-		ref $spec eq 'Regexp'? $sub_name =~ $spec:
-		ref $spec eq 'CODE'  ? $spec->($sub_name):
-		$spec eq $sub_name;
+
+
+
+
+######################################################################
+# Weaving Methods
+
+my %UNTOUCHABLE;
+BEGIN {
+	%UNTOUCHABLE = map { $_ => 1 } qw(
+		Carp
+		Carp::Heavy
+		Config
+		CORE
+		CORE::GLOBAL
+		DB
+		DB::fake
+		DynaLoader
+		Exporter
+		Exporter::Heavy
+		IO
+		IO::Handle
+		Regexp
+		Sub::Uplevel
+		UNIVERSAL
+		attributes
+		base
+		feature
+		fields
+		lib
+		strict
+		warnings
+		warnings::register
+	);
 }
 
-# weaving methods -------------------------------------------------------------
-
-my %UNTOUCHABLE = map { $_ => 1 } qw(
-	Carp
-	Carp::Heavy
-	Config
-	CORE
-	CORE::GLOBAL
-	DB
-	DB::fake
-	DynaLoader
-	Exporter
-	Exporter::Heavy
-	IO
-	IO::Handle
-	Regexp
-	UNIVERSAL
-	attributes
-	base
-	feature
-	fields
-	lib
-	strict
-	warnings
-	warnings::register
-);
-
 # Find the list of all matching subs
 sub match_all {
 	my $self    = shift;
@@ -88,16 +96,23 @@ sub match_define {
 	die("Method 'match_define' not implemented in class '$class'");
 }
 
-sub match_run {
-	my $class = ref $_[0] || $_[0];
-	die("Method 'match_run' not implemented in class '$class'");
-}
-
 sub curry_run {
 	my $class = ref $_[0] || $_[0];
 	die("Method 'curry' not implemented in class '$class'");
 }
 
+
+
+
+
+######################################################################
+# Runtime Methods
+
+sub match_run {
+	my $class = ref $_[0] || $_[0];
+	die("Method 'match_run' not implemented in class '$class'");
+}
+
 1;
 
 __END__
